# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [1.1.0] - 2022-12-12

### Added 

- Added `@sc_populate` decorator

## [1.0.1] - 2022-12-11

- Added `README.md` reference to PyPI project

## 1.0.0 - 2022-12-11

- First fully functional version

[1.1.0]: https://github.com/vsego/settings-collector/releases/tag/v1.1.0
[1.0.1]: https://github.com/vsego/settings-collector/releases/tag/v1.0.1
